pub fn sanitize_graph(graph: &EinsumGraph) -> EinsumGraphExpand description
Sanitize a graph by fixing common issues.
Currently performs:
- Deduplication of graph output indices.
The returned graph is independent of the input (cloned).
pub fn sanitize_graph(graph: &EinsumGraph) -> EinsumGraphSanitize a graph by fixing common issues.
Currently performs:
The returned graph is independent of the input (cloned).